ATE
===

.. currentmodule:: pqp.identification

.. autoclass:: ATE
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ATE.expression
      ~ATE.treatment_vars

   .. rubric:: Methods Documentation

   .. automethod:: expression
   .. automethod:: treatment_vars
